import peasy.*;

PImage img;
PeasyCam cam;
float[] rotations = new float[3];
String filename = "mandrill.png";

void setup() {
  size(480, 480, P3D);
  frameRate(15);
  textSize(18);
  img = loadImage(filename);
  cam = new PeasyCam(this, 512);
}

void draw() {
  background(255);

  // RGB cube
  noFill(); stroke(0); box(256);

  // color pixels
  translate(-128,-128,-128);
  int Npix = img.height * img.width;
  for(int i = 0; i < Npix; i++) {
    color c = img.pixels[i];
    stroke(c);
    point(red(c), green(c), blue(c));
  }

  // RGB axes
  rotations = cam.getRotations();

  pushMatrix();
  translate(-10,-10,-10);
  rotateX(rotations[0]);
  rotateY(rotations[1]);
  rotateZ(rotations[2]);
  fill(0);
  textAlign(CENTER);
  text("O",0,0,0);
  popMatrix();

  pushMatrix();
  translate(265,-10,-10);
  rotateX(rotations[0]);
  rotateY(rotations[1]);
  rotateZ(rotations[2]);
  fill(255,0,0);
  textAlign(CENTER);
  text("R",0,0,0);
  popMatrix();

  pushMatrix();
  translate(-10,265,-10);
  rotateX(rotations[0]);
  rotateY(rotations[1]);
  rotateZ(rotations[2]);
  fill(0,255,0);
  textAlign(CENTER);
  text("G",0,0,0);
  popMatrix();

  pushMatrix();
  translate(-10,-10,265);
  rotateX(rotations[0]);
  rotateY(rotations[1]);
  rotateZ(rotations[2]);
  fill(0,0,255);
  textAlign(CENTER);
  text("B",0,0,0);
  popMatrix();

  // File information
  cam.beginHUD();
  fill(0);
  textAlign(RIGHT);
  text(filename, 0, 0, width, 20);
  text("# pixels: "+ img.pixels.length, 0, 20, width, 20);
  image(img, 0, 0, 64, 64);
  cam.endHUD();
}

void keyPressed() {
  if(key == 'o' || key == 'O') {
    String loadPath = selectInput();  // Opens file chooser
    if (loadPath == null) {
      // If a file was not selected
      println("No file was selected...");
    } 
    else {
      try {
        img = loadImage(loadPath);
        filename = (new File(loadPath)).getName();
      }
      catch(Exception e) {
      }
      // If a file was selected, print path to file
      println(loadPath);
    }
  }
}

